[nautilus-actions] Have a more specific label when asking for export format



commit 42dfe0664b39a00832a99fc6272d0b81a5b948d5
Author: Pierre Wieser <pwieser trychlos org>
Date:   Fri Mar 5 22:18:56 2010 +0100

    Have a more specific label when asking for export format

 ChangeLog                  |    3 +++
 src/nact/nact-export-ask.c |    9 +++++++--
 2 files changed, 10 insertions(+), 2 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index c3534b8..928ef77 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,8 @@
 2009-03-05 Pierre Wieser <pwieser trychlos org>
 
+	* src/nact/nact-export-ask.c (on_base_runtime_init_dialog):
+	Set more clear label, whether the item be a label or an action.
+
 	* src/nact/nact-tree-model-dnd.c (get_xds_atom_value):
 	Remove debug traces after validation both on 32 and 64 bits systems.
 
diff --git a/src/nact/nact-export-ask.c b/src/nact/nact-export-ask.c
index 5bc058d..4f205c7 100644
--- a/src/nact/nact-export-ask.c
+++ b/src/nact/nact-export-ask.c
@@ -321,8 +321,13 @@ on_base_runtime_init_dialog( NactExportAsk *editor, gpointer user_data )
 
 	item_label = na_object_get_label( editor->private->item );
 
-	/* i18n: The item <label> is about to be exported */
-	label = g_strdup_printf( _( "The item \"%s\" is about to be exported." ), item_label );
+	if( NA_IS_OBJECT_ACTION( editor->private->item )){
+		/* i18n: The action <label> is about to be exported */
+		label = g_strdup_printf( _( "The action \"%s\" is about to be exported." ), item_label );
+	} else {
+		/* i18n: The menu <label> is about to be exported */
+		label = g_strdup_printf( _( "The menu \"%s\" is about to be exported." ), item_label );
+	}
 
 	widget = base_window_get_widget( BASE_WINDOW( editor ), "ExportAskLabel1" );
 	gtk_label_set_text( GTK_LABEL( widget ), label );



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]